export default {
    "message": "Unexpected token a",
    "column": 7,
    "index": 6,
    "lineNumber": 1
}